@@ -1,21 +1,13 @@
 APP_NAME_TO_USECASE = {
     "people_counting": "people_counting",
-    "customer_service": "customer_service",
-    "advanced_customer_service": "advanced_customer_service",
-    "security": "security",
-    "traffic": "traffic",
-    "sales": "sales",
-    "general": "general",
+    "mask_detection": "mask_detection",
+    "vehicle_type_monitoring": "vehicle_monitoring"
 }
 
 APP_NAME_TO_CATEGORY = {
     "people_counting": "general",
-    "customer_service": "sales",
-    "advanced_customer_service": "sales",
-    "security": "security",
-    "traffic": "traffic",
-    "sales": "sales",
-    "general": "general",
+    "mask_detection": "mask_detection",
+    "vehicle_type_monitoring": "traffic",
 }
 
 def get_usecase_from_app_name(app_name: str) -> str:
