@@ -206,11 +206,11 @@ class PotholeSegmentationUseCase(BaseProcessor):
         total_counts = self.get_total_counts()
         counting_summary['total_counts'] = total_counts
 
-        alerts = self._check_alerts(counting_summary, config)
+        alerts = self._check_alerts(counting_summary, frame_number, config)
         predictions = self._extract_predictions(processed_data)
         
         # Step: Generate structured events and tracking stats with frame-based keys
-        incidents_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
+        incidents_list = self._generate_incidents(counting_summary, alerts, config, frame_number, stream_info)
         tracking_stats_list = self._generate_tracking_stats(counting_summary, alerts, config, frame_number,stream_info)
         business_analytics_list = self._generate_business_analytics(counting_summary, alerts, config, frame_number, stream_info, is_empty=False)
         summary_list = self._generate_summary(counting_summary, incidents_list, tracking_stats_list, business_analytics_list, alerts)
