@@ -410,10 +410,10 @@ class WarehouseObjectUseCase(BaseProcessor):
         """Generate structured tracking stats matching eg.json format."""
         camera_info = self.get_camera_info_from_stream(stream_info)
         
-        frame_key = str(frame_number) if frame_number is not None else "current_frame"
-        tracking_stats = [{frame_key: []}]
-        frame_tracking_stats = tracking_stats[0][frame_key]
-        # tracking_stats = []
+        tracking_stats = []
+        # frame_key = str(frame_number) if frame_number is not None else "current_frame"
+        # tracking_stats = [{frame_key: []}]
+        # frame_tracking_stats = tracking_stats[0][frame_key]
         
         total_detections = counting_summary.get("total_count", 0) #CURRENT total count of all classes
         total_counts_dict = counting_summary.get("total_counts", {}) #TOTAL cumulative counts per class
@@ -438,7 +438,7 @@ class WarehouseObjectUseCase(BaseProcessor):
                     "category": cat,
                     "count": count
                 })
-
+        print(total_counts)
         # Build current_counts array in expected format  
         current_counts = []
         for cat, count in per_category_count.items():
@@ -447,7 +447,7 @@ class WarehouseObjectUseCase(BaseProcessor):
                     "category": cat,
                     "count": count
                 })
-
+        print(current_counts)
         # Prepare detections without confidence scores (as per eg.json)
         detections = []
         for detection in counting_summary.get("detections", []):
@@ -466,7 +466,7 @@ class WarehouseObjectUseCase(BaseProcessor):
             else:
                 detection_obj = self.create_detection_object(category, bbox)
             detections.append(detection_obj)
-
+        print(detections)
         # Build alert_settings array in expected format
         alert_settings = []
         if config.alert_config and hasattr(config.alert_config, 'alert_type'):
@@ -479,7 +479,7 @@ class WarehouseObjectUseCase(BaseProcessor):
                                     getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
                             }
             })
-
+        print(alert_settings)
         # Generate human_text in expected format
         human_text_lines = [f"Tracking Statistics:"]
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}")
@@ -508,13 +508,14 @@ class WarehouseObjectUseCase(BaseProcessor):
                     }
                 }
             ]
-
+        print(human_text)
         tracking_stat=self.create_tracking_stats(total_counts=total_counts, current_counts=current_counts,
                             detections=detections, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
                             reset_settings=reset_settings, start_time=high_precision_start_timestamp ,
                             reset_time=high_precision_reset_timestamp)
 
         tracking_stats.append(tracking_stat)
+        print(tracking_stats)
         return tracking_stats
 
     def _generate_business_analytics(self, counting_summary: Dict, zone_analysis: Dict, config: WarehouseObjectConfig, stream_info: Optional[Dict[str, Any]] = None, is_empty=False) -> List[Dict]:
